@@ -1,6 +1,6 @@
 # Gaussian model
 eNetXplorerGaussian <- function(x, y, family, alpha, nlambda, nlambda.ext, seed, scaled,
-n_fold, n_run, n_perm_null, QF.FUN, QF_label, cor_method, ...)
+n_fold, n_run, n_perm_null, save_lambda_QF_full, QF.FUN, QF_label, cor_method, ...)
 {
     n_instance = nrow(x)
     n_feature = ncol(x)
@@ -58,6 +58,7 @@ n_fold, n_run, n_perm_null, QF.FUN, QF_label, cor_method, ...)
     
     lambda_values = vector("list",n_alpha)
     lambda_QF_est = vector("list",n_alpha)
+    lambda_QF_est_full = vector("list",n_alpha)
     
     foldid_per_run = vector("list",n_alpha)
     predicted_values = vector("list",n_alpha)
@@ -95,6 +96,8 @@ n_fold, n_run, n_perm_null, QF.FUN, QF_label, cor_method, ...)
         names(lambda_values) = alpha_label
         lambda_QF_est = lambda_QF_est[1:n_alpha_eff]
         names(lambda_QF_est) = alpha_label
+        lambda_QF_est_full = lambda_QF_est_full[1:n_alpha_eff]
+        names(lambda_QF_est_full) = alpha_label
         feature_coef_wmean = feature_coef_wmean[,1:n_alpha_eff,drop=F]
         rownames(feature_coef_wmean) = feature
         colnames(feature_coef_wmean) = alpha_label
@@ -136,13 +139,13 @@ n_fold, n_run, n_perm_null, QF.FUN, QF_label, cor_method, ...)
         # input data and parameters
         predictor = as(x,"CsparseMatrix"), response = y, alpha = alpha[1:n_alpha_eff], family = family, nlambda = nlambda,
         nlambda.ext = nlambda.ext, seed = seed, scaled = scaled, n_fold = n_fold, n_run = n_run,
-        n_perm_null = n_perm_null,
+        n_perm_null = n_perm_null, save_lambda_QF_full = save_lambda_QF_full,
         QF_label = QF_label, cor_method = cor_method, instance = instance,
         feature = feature, glmnet_params = glmnet.control(),
         # summary results
         best_lambda = best_lambda, model_QF_est = model_QF_est, QF_model_vs_null_pval = QF_model_vs_null_pval,
         # detailed results for plots and downstream analysis
-        lambda_values = lambda_values, lambda_QF_est = lambda_QF_est,
+        lambda_values = lambda_values, lambda_QF_est = lambda_QF_est, lambda_QF_est_full = lambda_QF_est_full,
         predicted_values = predicted_values,
         feature_coef_wmean = as(feature_coef_wmean,"CsparseMatrix"), feature_coef_wsd = as(feature_coef_wsd,"CsparseMatrix"),
         feature_freq_mean = as(feature_freq_mean,"CsparseMatrix"), feature_freq_sd = as(feature_freq_sd,"CsparseMatrix"),
@@ -211,6 +214,9 @@ n_fold, n_run, n_perm_null, QF.FUN, QF_label, cor_method, ...)
                 }
                 pb$tick()
             }
+            if (save_lambda_QF_full) {
+                lambda_QF_est_full[[i_alpha]] = lambda_QF_est_all_runs
+            }
             lambda_QF_est[[i_alpha]] = apply(lambda_QF_est_all_runs,1,median,na.rm=T)
             best_lambda_index = which.max(lambda_QF_est[[i_alpha]])
             
