@@ -4,6 +4,7 @@ xlab=NULL, ylab=NULL, cex.lab=0.95, main=NULL, col.main = "black", cex.main=0.85
 instance.label=TRUE,
 instance.label.cex=NULL, instance.label.offset=NULL,
 instance.label.added.margin=NULL, col=NULL, # numerical only
+box.wex=NULL, box.range=NULL, box.col=NULL,
 transparency=NULL, jitter=NULL, cex.pt=NULL, class.color=NULL, # categorical only
 ...)
 {
@@ -32,6 +33,15 @@ transparency=NULL, jitter=NULL, cex.pt=NULL, class.color=NULL, # categorical onl
         if (is.null(instance.label.offset)) {
             instance.label.offset = 0.6
         }
+        if (is.null(box.wex)) {
+            box.wex = 0.5
+        }
+        if (is.null(box.range)) {
+            box.range = 0
+        }
+        if (is.null(box.col)) {
+            box.col = "white"
+        }
         if (is.null(transparency)) {
             transparency = 70
         }
@@ -41,7 +51,9 @@ transparency=NULL, jitter=NULL, cex.pt=NULL, class.color=NULL, # categorical onl
         if (is.null(cex.pt)) {
             cex.pt = 1.7
         }
-        plotMeasuredVsOOBCateg(x=x, alpha.index=alpha.index, xlab=xlab, ylab=ylab, cex.lab=cex.lab, main=main, col.main=col.main, cex.main=cex.main, instance.label=instance.label, instance.label.cex=instance.label.cex, instance.label.offset=instance.label.offset, transparency=transparency, jitter=jitter, cex.pt=cex.pt, class.color=class.color, ...)
+        plotMeasuredVsOOBCateg(x=x, alpha.index=alpha.index, xlab=xlab, ylab=ylab, cex.lab=cex.lab, main=main, col.main=col.main, cex.main=cex.main, instance.label=instance.label, instance.label.cex=instance.label.cex, instance.label.offset=instance.label.offset,
+            box.wex=box.wex, box.range=box.range, box.col=box.col,
+            transparency=transparency, jitter=jitter, cex.pt=cex.pt, class.color=class.color, ...)
     }
 }
 
