@@ -5,11 +5,11 @@ knitr::opts_chunk$set(echo = TRUE)
 #  install.packages("eNetXplorer")
 
 ## ---- message=FALSE-----------------------------------------------------------
-data_gen <- function(n_inst, covmat, seed=123) {
+data_gen_pop_covmat <- function(n_inst, covmat, seed=123) {
     library (expm);
     set.seed(seed)
     data <- matrix(rnorm(n_inst*ncol(covmat)),ncol=ncol(covmat))%*%sqrtm(covmat)
-    predictor=data[,-1]
+    predictor=data[,-1,drop=F]
     rownames(predictor) = paste0("Inst.",1:n_inst)
     colnames(predictor) = paste0("Feat.",1:(ncol(covmat)-1))
     list(response=data[,1],predictor=predictor)
@@ -35,7 +35,7 @@ covmat_gen <- function(n_pred, block_size, r_resp, r_block) {
 }
 
 ## ---- message=FALSE-----------------------------------------------------------
-data = data_gen(n_inst=50, covmat_gen(n_pred=60, block_size=5, r_resp=0.5, r_block=0.35))
+data = data_gen_pop_covmat(n_inst=50, covmat_gen(n_pred=60, block_size=5, r_resp=0.5, r_block=0.35))
 
 ## ---- echo=FALSE, message=FALSE, fig.height = 4.5, fig.width = 6.5, fig.align = "left"----
 library(gplots)
@@ -82,7 +82,7 @@ plot(fit, alpha.index = which.max(fit$model_QF_est), plot.type="lambdaVsQF")
 plot(fit, alpha.index = which.max(fit$model_QF_est), plot.type="measuredVsOOB") 
 
 ## -----------------------------------------------------------------------------
-data = data_gen(n_inst=50, covmat_gen(n_pred=60, block_size=1, r_resp=0.7, r_block=0.35))
+data = data_gen_pop_covmat(n_inst=50, covmat_gen(n_pred=60, block_size=1, r_resp=0.7, r_block=0.35))
 
 ## ---- echo=FALSE, fig.height = 4.5, fig.width = 6.5, fig.align = "left"-------
 library(gplots)
@@ -132,3 +132,94 @@ plot(fit, alpha.index = which.max(fit$model_QF_est), plot.type="featureHeatmap",
 #  miR_filtered = Leuk_miR_full$miR_metadata[miR_filter,]
 #  sample_filtered = Leuk_miR_full$sample_metadata[sample_filter,]
 
+## ---- eval=FALSE--------------------------------------------------------------
+#  data(breastCancerSurv)
+
+## ---- echo=FALSE--------------------------------------------------------------
+# OR, for our purposes, we upload the object previously generated:
+load("eNet_gaussian_covsam_null.Robj")
+
+## ---- warning=FALSE, tidy=TRUE, fig.height = 4, fig.width = 5.5, fig.align = "left"----
+plot(eNet, alpha.index = which.max(eNet$model_QF_est), plot.type="measuredVsOOB") 
+
+## ---- message=FALSE-----------------------------------------------------------
+data_gen_sampl_covmat <- function(n_inst, covmat) {
+    library (expm)
+    mat <- matrix(rnorm(n_inst*ncol(covmat)),ncol=ncol(covmat))
+    data = mat%*%sqrtm(solve(cov(mat)))%*%sqrtm(covmat)
+    predictor=data[,-1,drop=F]
+    rownames(predictor) = paste0("Inst.",1:n_inst)
+    colnames(predictor) = paste0("Feat.",1:(ncol(covmat)-1))
+    list(response=data[,1],predictor=predictor)
+}
+
+## ---- message=FALSE-----------------------------------------------------------
+n_inst=50
+n_fold = 5
+foldid = NULL
+fold_size = floor(n_inst/n_fold)
+for (i_fold in 1:n_fold) {
+    foldid = c(foldid,rep(i_fold,fold_size))
+}
+fold_rest = n_inst%%n_fold
+if (fold_rest>0) {
+    for (i_fold in 1:fold_rest) {
+        foldid = c(foldid,i_fold)
+    }
+}
+
+## ---- warning=FALSE, message=FALSE--------------------------------------------
+n_run = 20
+n_rdm = 10
+set.seed(123)
+cor_data = rep(NA,n_run)
+cor_pred_full = rep(NA,n_run)
+cor_pred_OOB_mean = rep(NA,n_run)
+cor_pred_OOB_sd = rep(NA,n_run)
+covmat=matrix(c(1,0,0,1),ncol=2)
+for (i_run in 1:n_run) {
+    data_gen = data_gen_sampl_covmat(n_inst,covmat)
+    data = data.frame(x=data_gen$predictor[,1],y=data_gen$response)
+    cor_data[i_run] = cor(data$x,data$y)
+    fit = lm("y~x",data)
+    y_pred = predict(fit,data)
+    cor_pred_full[i_run] = cor(data$y,y_pred)
+    # we generate random folds
+    cor_pred_OOB = rep(NA,n_rdm)
+    for (i_rdm in 1:n_rdm) {
+        foldid_rdm = sample(foldid)
+        y_pred_rdm = rep(NA,n_inst)
+        for (i_fold in 1:n_fold) {
+            IB = foldid_rdm!=i_fold
+            fit = lm("y~x",data[IB,])
+            y_pred_rdm[!IB] = predict(fit,data[!IB,])
+        }
+        cor_pred_OOB[i_rdm] = cor(data$y,y_pred_rdm)
+    }
+    cor_pred_OOB_mean[i_run] = mean(cor_pred_OOB)
+    cor_pred_OOB_sd[i_run] = sd(cor_pred_OOB)
+}
+
+## ---- warning=FALSE, tidy=TRUE, fig.height = 4, fig.width = 5.5, fig.align = "left"----
+color = c("black","blue","red")
+x = 1:n_run
+range_y = range(cor_data,cor_pred_full,cor_pred_OOB_mean+cor_pred_OOB_sd,
+                cor_pred_OOB_mean-cor_pred_OOB_sd,na.rm=T)
+plot(range(x),range_y,type="n",xlab="run",ylab="Pearson's correlation",cex.lab=1.)
+lines(x,cor_data,type="b",pch=16,col=color[1],lty=3)
+lines(x,cor_pred_full,type="b",pch=16,col=color[2],lty=3)
+lines(x,cor_pred_OOB_mean,type="b",pch=16,col=color[3],lty=3)
+arrows(x,cor_pred_OOB_mean-cor_pred_OOB_sd,x,cor_pred_OOB_mean+cor_pred_OOB_sd,col=color[3],length=0.025,angle=90,code=3)
+legend_txt = c("cor(y,x)","cor(y,y_pred)","cor(y,y_pred_OOB)")
+legend(11,-0.075,legend_txt,pch=16,lwd=1,col=color,lty=3,cex=0.7,pt.cex=0.7) 
+
+## ---- eval=FALSE--------------------------------------------------------------
+#  library(furrr)
+#  data(QuickStartEx)
+#  alpha_values = seq(0,1,by=0.2)
+#  future::plan(multiprocess) # Set up parallel processing
+#  eNet = alpha_values %>% furrr::future_map(~ eNetXplorer(
+#    x=QuickStartEx$predictor, y=QuickStartEx$response,family="gaussian",
+#    n_run=20,n_perm_null=10,save_obj=T,dest_obj=paste0("eNet_a",.x,".Robj"),alpha=.x))
+#  mergeObj(paste0("eNet_a",alpha_values,".Robj"))
+
